#!/bin/bash

# This script is started just before the user job
# It is referenced by the USER_JOB_WRAPPER

export HOME=$PWD

# fix PATH and LD_LIBRARY_PATH
export PATH=$PATH:/usr/bin:/bin
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/usr/local/lib64:/usr/local/lib:/usr/lib64:/usr/lib:/usr/lib/x86_64-linux-gnu:/lib64:/lib:/lib/x86_64-linux-gnu

# hide all GPUs unless job actually requested a GPU.
export CUDA_VISIBLE_DEVICES COMPUTE GPU_DEVICE_ORDINAL
gpu_dev=$(grep -e "^AssignedGPUs" $_CONDOR_MACHINE_AD | awk -F "= " "{print \$2}" | sed "s/CUDA//g" | sed "s/OCL//g" | sed "s/\"//g")
if [ -n "$gpu_dev" ]; then
  export CUDA_VISIBLE_DEVICES=$gpu_dev
  export COMPUTE=:0.$gpu_dev
  export GPU_DEVICE_ORDINAL=$gpu_dev
fi

GLIDEIN_DIR=$GLIDEIN_LOCAL_TMP_DIR
if [ ! -d $GLIDEIN_DIR ]; then
    GLIDEIN_DIR=$PWD
fi
JOB_WRAPPER="${GLIDEIN_DIR}/job_wrapper.sh"


# idbox TODO:
#  - run ssh_to_job shell under parrot idbox or disable ssh_to_job
#  - in real idbox mode, we must not allow any jobs to run without being wrapped by parrot
#  - do not run this script in user-controlled environment

# run a command with clean environment
safe() {
  /usr/bin/env -i "$@"
}

# fall through to next/default job wrapper
if [ ! -e $JOB_WRAPPER ]; then
    exec "$@"
else
    exec ${JOB_WRAPPER} "$@"
fi
